@@ -804,7 +804,7 @@ def _arbitrary(translator, expr):
 class NumericTruncate(ops.NumericBinaryOp):
     """Truncates x to y decimal places."""
 
-    output_type = rlz.shape_like('left', ops.dt.float)
+    output_type = rlz.shape_like('left', dt.float)
 
 
 # GEOMETRIC
@@ -813,13 +813,13 @@ class NumericTruncate(ops.NumericBinaryOp):
 class Conv_4326_900913_X(ops.UnaryOp):
     """Converts WGS-84 latitude to WGS-84 Web Mercator x coordinate."""
 
-    output_type = rlz.shape_like('arg', ops.dt.float)
+    output_type = rlz.shape_like('arg', dt.float)
 
 
 class Conv_4326_900913_Y(ops.UnaryOp):
     """Converts WGS-84 longitude to WGS-84 Web Mercator y coordinate."""
 
-    output_type = rlz.shape_like('arg', ops.dt.float)
+    output_type = rlz.shape_like('arg', dt.float)
 
 
 # String
